/*
 * Copyright (c) xFusion Digital Technologies Co., Ltd. 2014-2019. All rights reserved.
 * Description: alarm registration and forwarding
 * Author: yangbin
 */

#ifndef __ALARM_H__
#define __ALARM_H__

#include <sys/time.h>

#define ALARM_LEVEL_CRITICAL 1
#define ALARM_LEVEL_MAJOR 2
#define ALARM_LEVEL_MINOR 3
#define ALARM_LEVEL_WARNING 4
#define ALARM_LEVEL_INDETERMINATE 5

#define COMMON_ALARM_TYPE_EVENT 2
#define COMMON_ALARM_TYPE_OCCUR 1
#define COMMON_ALARM_TYPE_RESUME 0

#define MAX_PARAS_LEN 256

struct del_alarm_info_extend {
    unsigned short usAlarmId;
    unsigned char ucAlarmLevel;
    unsigned char ucAlarmType;
    struct timeval stAlarmTime; /* alarm time info in alarm record */
    unsigned char pucParas[MAX_PARAS_LEN];
    unsigned char pucExParas[MAX_PARAS_LEN];
    int AlarmTime;
};

/*
 * Description  :上报告警
 * Input        :
 * （1）usAlarmId：unsigned short，告警id，某一类故障一个id，id定义避免重复。
 * （2）ucAlarmLevel: unsigned char，告警级别，表示紧急、重要、次要、提示、不确定
 * （3）ucAlarmType：unsigned char，告警类别，表示告警产生或告警恢复
 *   （对用户呈现需要用户操作的告警恢复后需要上报告警恢复）
 * （4）pucParas：unsigned char*，告警描述信息
 * （5）pucExParas: unsigned char*，告警拓展描述信息，告警产生的设备名
 * Output       : 无
 * Return       : 0:成功；!=0:失败
 * Notes        : 该函数不支持多线程,不是信号安全函数
 */
int os_alarm(unsigned short usAlarmId, unsigned char ucAlarmLevel, unsigned char ucAlarmType, unsigned char *pucParas,
    unsigned char *pucExParas);

/*
 * Description  : 外部接口用于删除告警记录, 从当前时间算起，n分钟前的告警全部删除，
 *                n为AlarmTime, 单位为min，如果n为0，则将此ID的告警全部删除
 * Input        : usAlarmId, AlarmTime
 * Output       : 无
 * Return       : 0:成功 -1:失败
 * Notes        : 该函数不支持多线程,不是信号安全函数
 */
int os_alarm_del(unsigned short usAlarmId, int AlarmTime);

/*
 *  Description  : 外部接口用于删除告警记录, 当前支持匹配告警id，告警扩展信息，以及告警时间
 *                 (从当前时间算起，n分钟前的告警全部删除，n为AlarmTime, 单位为min，如果n为0，则将此ID的告警全部删除)
 *  Input        : struct del_alarm_info_extend * del_info
 *  Output       : 无
 *  Return       : 0:成功 -1:失败
 *  Notes        : 该函数不支持多线程,不是信号安全函数
 */
int os_alarm_del_extend(const struct del_alarm_info_extend *del_info);

/*
 * Description   : 退出时删除fd资源占用 os_alarm发送告警接口用到
 * Notes         : 该函数不支持多线程,不是信号安全函数
 */
void close_alarm(void);
/*
 * Description   : 退出时删除fd资源占用 os_alarm_del删除告警接口用到
 * Notes         : 该函数不支持多线程,不是信号安全函数
 */
void close_delalarm(void);

#endif
