/*
 * Copyright (c) xFusion Digital Technologies Co., Ltd. 2014-2019. All rights reserved.
 * Description: alarm registration and forwarding
 * Author: yangbin
 */

#ifndef __REGISTER_H__
#define __REGISTER_H__

/*
 * alarm_report_func 参数解释
 * （1）usAlarmId：unsigned short，告警id，某一类故障一个id，id定义避免重复。
 * （2）ucAlarmType：unsigned char，告警类别，表示告警产生或告警恢复（对用户呈现需要用户操作的告警恢复后需要上报告警恢复）
 * （3）ucParasLen：unsigned char，告警描述信息的长度
 * （4）pucParas：unsigned char*，告警描述信息
 * hooker回调函数处理
 * Notes        : 下述函数不支持多线程,不是信号安全函数
 */
typedef int (*alarm_report_func)(unsigned short, unsigned char, unsigned char, unsigned char *);
typedef int (*alarm_callback_func)(void *palarm);

struct alarm_hook_struct {
    alarm_report_func pfunc_alarmreport;
};

struct alarm_hook {
    alarm_callback_func pfunc_alarmcallbk;
};

/*
 * Return       : 0－成功，非0－失败
 * Notes        : 下述函数不支持多线程,不是信号安全函数
 */
int OS_HookRegister(struct alarm_hook_struct *alarm); /* 旧版本接口 */
int OS_alarm_Register(struct alarm_hook *alarm);      /* 新版本接口 */

/*
 * Description  : 注销告警注册接口
 * Notes        : 下述函数不支持多线程,不是信号安全函数
 */
void OS_UnHookRegister(void);   /* 旧版本接口 */
void OS_alarm_UnRegister(void); /* 新版本接口 */

/*
 * Description  : 获得告警各项信息(告警id, 类型, 级别，时间，描述信息，拓展信息)接口
 * Notes        : 下述函数不支持多线程,不是信号安全函数
 */
unsigned short OS_alarm_getid(const void *palarm);
unsigned char OS_alarm_gettype(const void *palarm);
unsigned char OS_alarm_getlevel(const void *palarm);
long long OS_alarm_gettime(const void *palarm);
char *OS_alarm_getdesc(const void *palarm);
char *OS_alarm_getexdesc(const void *palarm);

/*
 * Description  : 触发告警信息重新上报 该接口为阻塞模式，当告警全部上报完成，才返回
 *                当调用者进程出现异常终止或退出，会停止告警重新上报
 * Input        : flag [IN]：告警上报类型标记
 *                 0 全部告警重新上报
 *                 1 产生告警重新上报
 *                 2 恢复告警重新上报
 * Output       : 无
 * Return       : 0:成功 -1:失败 1:resubmit正在执行 2:停止resubmit命令下发
 * Notes        : 该函数不支持多线程,不是信号安全函数
 */
int OS_alarm_resubmit(int flag);

/*
 * Description  : 触发告警信息停止重新上报
 * Input        : 无
 * Output       : 无
 * Return       : 0:成功 -1:失败
 * Notes        : 该函数不支持多线程,不是信号安全函数
 */
int OS_alarm_resubmit_stop(void);

#endif
